<!-- CHUNK ID: chunk_0D45C98F  CHUNK TYPE: header START_LINE:1 -->
### Advanced

<!-- CHUNK ID: chunk_F16EF37C  CHUNK TYPE: paragraph START_LINE:3 -->
This section is intended for advanced users of this software. Here you can find:

<!-- CHUNK ID: chunk_5FC80BEA  CHUNK TYPE: list START_LINE:5 -->
1. [**Advanced Usage**](./advanced.md)
<!-- CHUNK ID: chunk_7B3D7A76  CHUNK TYPE: paragraph START_LINE:6 -->
<br>
In this section, you can explore specify source/target languages, switch translation services, and more.

<!-- CHUNK ID: chunk_7A0A4B36  CHUNK TYPE: list START_LINE:9 -->
2. [**Language Code**](./Language-Codes.md)
<!-- CHUNK ID: chunk_298EB9AE  CHUNK TYPE: paragraph START_LINE:10 -->
<br>
If you are unsure about which codes to use for translating your source/target languages, you can find them here.

<!-- CHUNK ID: chunk_A956AA16  CHUNK TYPE: list START_LINE:13 -->
3. [**Documentation of Translation Services**](./Documentation-of-Translation-Services.md)
<!-- CHUNK ID: chunk_49F0D79D  CHUNK TYPE: paragraph START_LINE:14 -->
<br>
If you need to review the documentation provided by the translation services you are using, please refer to this page.